#
# spec file for package python-tabulate
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-tabulate
Version:        0.9.0
Release:        150400.11.7.4
Summary:        Pretty-printer for tabular data in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://bitbucket.org/astanin/python-tabulate
Source:         https://files.pythonhosted.org/packages/source/t/tabulate/tabulate-%{version}.tar.gz
BuildRequires:  %{python_module base > 3.6}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools >= 61.2.0}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wcwidth}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
Recommends:     python-wcwidth
Suggests:       python-pandas
BuildArch:      noarch
%python_subpackages

%description
Pretty-printer for tabular data in Python.

The main use cases of the library are:

 * printing small tables without hassle: just one function call,
   formatting is guided by the data itself
 * authoring tabular data for lightweight plain-text markup: multiple
   output formats suitable for further editing or transformation
 * readable presentation of mixed textual and numeric data: smart
   column alignment, configurable number formatting, alignment by a
   decimal point

%prep
%setup -q -n tabulate-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/tabulate
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative tabulate

%postun
%python_uninstall_alternative tabulate

%files %{python_files}
%license LICENSE
%doc README.md
%python_alternative %{_bindir}/tabulate
%{python_sitelib}/tabulate
%{python_sitelib}/tabulate-%{version}.dist-info

%changelog
* Fri May 19 2023 dmueller@suse.com
- build with setuptools_scm
* Fri Apr 21 2023 dmueller@suse.com
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Feb 16 2023 simmphonie@opensuse.org
- update to version 0.9.0
  * Drop support for Python 2.7, 3.5, 3.6.
  * Migrate to pyproject.toml project layout (PEP 621).
  * New output formats: `asciidoc`, various `*grid` and `*outline` formats.
  * New output features: vertical row alignment, separating lines.
  * New input format: list of dataclasses (Python 3.7 or later).
  * Support infinite iterables as row indices.
  * Improve column width options.
  * Improve support for ANSI escape sequences and document the behavior.
  * Various bug fixes.
* Mon Jul 11 2022 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.8.10:
  * Python 3.10 support.
  * Bug fixes.
  * Column width parameter.
* Wed Sep 29 2021 steven.kowalik@suse.com
- Remove unneeded BuildRequires on nose.
* Fri Jul 16 2021 dmueller@suse.com
- update to 0.8.9:
  * Bug fix. Revert support of decimal separators.
  * Python 3.9 support, 3.10 ready.
  * New formats: ``unsafehtml``, ``latex_longtable``, ``fancy_outline``.
  * Support lists of UserDicts as input.
  * Support hyperlinks in terminal output.
  * Improve testing on systems with proxies.
  * Migrate to pytest.
  * Various bug fixes and improvements.
* Wed Jan 13 2021 pgajdos@suse.com
- use %%pytest macro
* Tue May 19 2020 pgajdos@suse.com
- %%python3_only -> %%python_alternative
* Sat Apr 25 2020 arun@gmx.de
- update to version 0.8.7:
  * Bug fixes.
  * New format: `pretty`.
  * HTML escaping.
* Tue Mar 10 2020 dmueller@suse.com
- remove pandas dependency (optional test dependency, and went python 3.x only)
* Sun Dec  1 2019 arun@gmx.de
- specfile:
  * be more specific in %%files section
- update to version 0.8.6:
  * Bug fixes.
  * Stop supporting Python 3.3, 3.4.
* Tue Oct  8 2019 tchvatal@suse.com
- Update to 0.8.5:
  * various bugfixes
- Remove merged pr_2.patch
* Sat Sep 14 2019 jayvdb@gmail.com
- Add pr_2.patch to fix tests to use sys.executable
* Wed Feb  6 2019 jengelh@inai.de
- Use noun phrase in summary.
* Wed Feb  6 2019 jayvdb@gmail.com
- Update to 0.8.3
  * Bug fixes
  * New format: `github`
  * Custom colum alignment
- Recommend wcwidth needed for wide character support
- Suggest pandas which is supported
- Run tests for wcwidth and pandas
* Tue Mar 27 2018 tchvatal@suse.com
- Add python-setuptools to Requires
* Mon Mar 26 2018 matthias.eliasson@gmail.com
- Update to 0.8.2
  * Bugfix release
- Changes from 0.8.1
  * Multiline data in several output formats. New latex_raw format.
  * Column-specific floating point formatting.
  * Python 3.5 & 3.6 support.
  * Drop support for Python 2.6, 3.2, 3.3 (should still work).
- Run spec-cleaner
* Thu Apr 20 2017 sflees@suse.de
- Update to 0.7.7
  * support. Iterables of dicts. ``latex_booktabs`` format.
  * ```fancy_grid`` and ``html`` formats. Command line utility.
  * ``--float`` format option for the command line utility.
  * New table formats (``psql``, ``jira``, ``moinmoin``, ``textile``).
  * Wide character support.
  * Printing from database cursors.
  * Option to print row indices.
  * Boolean columns. Ragged rows.
  * Option to disable number parsing.
  * Bug Fixes
- Convert to single spec
* Wed Jul  6 2016 tbechtold@suse.com
- Add LICENSE and README
* Thu Jul 24 2014 fcastelli@suse.com
- Remove python-setuptools requirement
* Wed Jul 23 2014 fcastelli@suse.com
- Initial version of the package (0.7.2)
